Prepare for SoC rework of ARM code:
- rename CONFIG_BOOTBINFUNC into  CONFIG_INIT_CRITICAL
- rename memsetup into lowlevel_init (function name and source files)
diff --git a/board/gcplus/Makefile b/board/gcplus/Makefile
index d0f7d1c..1954d66 100644
--- a/board/gcplus/Makefile
+++ b/board/gcplus/Makefile
@@ -28,7 +28,7 @@
 LIB	= lib$(BOARD).a
 
 OBJS	:= gcplus.o flash.o
-SOBJS	:= memsetup.o
+SOBJS	:= lowlevel_init.o
 
 $(LIB):	$(OBJS) $(SOBJS)
 	$(AR) crv $@ $(OBJS) $(SOBJS)
diff --git a/board/gcplus/memsetup.S b/board/gcplus/lowlevel_init.S
similarity index 94%
rename from board/gcplus/memsetup.S
rename to board/gcplus/lowlevel_init.S
index 02f5685..f292c4d 100644
--- a/board/gcplus/memsetup.S
+++ b/board/gcplus/lowlevel_init.S
@@ -29,11 +29,11 @@
 #include "version.h"
 
 
-	.globl	memsetup
-memsetup:
+	.globl	lowlevel_init
+lowlevel_init:
 	/* The ADS GC+ for Linux Boot Rom Ver. 1.73 does memory init for us.
 	 * However the darn thing leaves the MMU enabled before handing control
 	 * over to us. So we need to disable the MMU and we use memsetup
 	 * to do it.
 	 */
@@ -29,11 +29,11 @@
 	/* The ADS GC+ for Linux Boot Rom Ver. 1.73 does memory init for us.
 	 * However the darn thing leaves the MMU enabled before handing control
-	 * over to us. So we need to disable the MMU and we use memsetup
+	 * over to us. So we need to disable the MMU and we use lowlevel_init
 	 * to do it.
 	 */